"""
Simple test API for timeseries management
"""

from typing import List
from fastapi import FastAPI, Depends, HTTPException, Body
from sqlalchemy.orm import Session
from . import crud, schemas
from utils.database import ToarDbSession

app = FastAPI()

# Dependency
def get_db():
    try:
        db = ToarDbSession()
        yield db
    finally:
        db.close()



# plain views to post and get timeseries

#get all entries of table timeseries
@app.get('/timeseries/', response_model=List[schemas.Timeseries])
def get_all_timeseries(skip: int = 0, limit: int = None, db: Session = Depends(get_db)):
    timeseries = crud.get_all_timeseries(db, skip=skip, limit=limit)
    return timeseries

#get all metadata of one timeseries
@app.get('/timeseries/{timeseries_id}', response_model=schemas.Timeseries)
def get_timeseries(timeseries_id: int, db: Session = Depends(get_db)):
    db_timeseries = crud.get_timeseries(db, timeseries_id=timeseries_id)
    if db_timeseries is None:
        raise HTTPException(status_code=404, detail="Timeseries not found.")
    return db_timeseries

#some more gets to be tested:
#
#
#

# still to be tested:
@app.post('/timeseries/', response_model=schemas.Timeseries)
def create_timeseries(timeseries: schemas.TimeseriesCreate = Body(..., embed = True), db: Session = Depends(get_db)):
    db_timeseries = crud.get_timeseries(db, timeseries_id=timeseries.id)
    if db_timeseries:
        raise HTTPException(status_code=400, detail="Timeseries already registered.")
    return crud.create_timeseries(db=db, timeseries=timeseries)
